@@ -31,12 +31,6 @@
 #define arma_noinline
 #define arma_ignore(variable)  ((void)(variable))
 
-// arma_pure and arma_const kept only for compatibility with old code
-#undef  arma_pure
-#define arma_pure
-#undef  arma_const
-#define arma_const
-
 #undef arma_fortran_noprefix
 #undef arma_fortran_prefix
 
@@ -66,16 +60,6 @@
 #define ARMA_INCFILE_WRAP(x) <x>
 
 
-#if defined(__CYGWIN__)
-  #if defined(ARMA_USE_CXX11)
-    #pragma message ("WARNING: Cygwin may have incomplete support for C++11 features;")
-    #pragma message ("WARNING: if something breaks, you get to keep all the pieces.")
-    #pragma message ("WARNING: to forcefully prevent Armadillo from using C++11 features,")
-    #pragma message ("WARNING: #define ARMA_DONT_USE_CXX11 before #include <armadillo>")
-  #endif
-#endif
-
-
 #if defined(ARMA_USE_CXX11)
   
   #undef  ARMA_USE_U64S64
@@ -140,7 +124,7 @@
 #endif
 
 
-#if defined(__MINGW32__)
+#if defined(__MINGW32__) || defined(__CYGWIN__) || defined(_MSC_VER)
   #undef ARMA_HAVE_POSIX_MEMALIGN
 #endif
 
@@ -171,10 +155,15 @@
   #undef  ARMA_GCC_VERSION
   #define ARMA_GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
   
-  #if (ARMA_GCC_VERSION < 40200)
+  #if (ARMA_GCC_VERSION < 40400)
     #error "*** Need a newer compiler ***"
   #endif
   
+  #if (ARMA_GCC_VERSION < 40600)
+    #pragma message ("WARNING: this compiler is OUTDATED and has INCOMPLETE support for the C++ standard;")
+    #pragma message ("WARNING: if something breaks, you get to keep all the pieces.")
+  #endif
+  
   #if ( (ARMA_GCC_VERSION >= 40700) && (ARMA_GCC_VERSION <= 40701) )
     #error "gcc versions 4.7.0 and 4.7.1 are unsupported; use 4.7.2 or later"
     // due to http://gcc.gnu.org/bugzilla/show_bug.cgi?id=53549
@@ -182,6 +171,8 @@
   
   #define ARMA_GOOD_COMPILER
   
+  #undef  arma_hot
+  #undef  arma_cold
   #undef  arma_aligned
   #undef  arma_align_mem
   #undef  arma_warn_unused
@@ -190,6 +181,8 @@
   #undef  arma_inline
   #undef  arma_noinline
   
+  #define arma_hot                __attribute__((__hot__))
+  #define arma_cold               __attribute__((__cold__))
   #define arma_aligned            __attribute__((__aligned__))
   #define arma_align_mem          __attribute__((__aligned__(16)))
   #define arma_warn_unused        __attribute__((__warn_unused_result__))
@@ -203,28 +196,17 @@
   
   #if defined(ARMA_USE_CXX11)
     #if (ARMA_GCC_VERSION < 40800)
-      #pragma message ("WARNING: compiler is in C++11 mode, but it has INCOMPLETE support for C++11 features;")
-      #pragma message ("WARNING: if something breaks, you get to keep all the pieces.")
-      #pragma message ("WARNING: to forcefully prevent Armadillo from using C++11 features,")
-      #pragma message ("WARNING: #define ARMA_DONT_USE_CXX11 before #include <armadillo>")
-      #define ARMA_DONT_USE_CXX11_CHRONO
+      #undef  ARMA_PRINT_CXX11_WARNING
+      #define ARMA_PRINT_CXX11_WARNING
     #endif
   #endif
   
-  #if !defined(ARMA_USE_CXX11)
+  #if !defined(ARMA_USE_CXX11) && !defined(__GXX_EXPERIMENTAL_CXX0X__) && (__cplusplus < 201103L) 
     #if defined(_GLIBCXX_USE_C99_MATH_TR1) && defined(_GLIBCXX_USE_C99_COMPLEX_TR1)
       #define ARMA_HAVE_TR1
     #endif
   #endif
   
-  #if (ARMA_GCC_VERSION >= 40300)
-    #undef  arma_hot
-    #undef  arma_cold
-    
-    #define arma_hot  __attribute__((__hot__))
-    #define arma_cold __attribute__((__cold__))
-  #endif
-  
   #if (ARMA_GCC_VERSION >= 40700)
     #define ARMA_HAVE_GCC_ASSUME_ALIGNED
   #endif
@@ -236,7 +218,7 @@
     #define ARMA_SIMPLE_LOOPS
   #endif
   
-  #if (defined(_POSIX_C_SOURCE) && (_POSIX_C_SOURCE >= 200112L))
+  #if !defined(ARMA_USE_CXX11) && (defined(_POSIX_C_SOURCE) && (_POSIX_C_SOURCE >= 200112L))
     #define ARMA_HAVE_SNPRINTF
     #define ARMA_HAVE_ISFINITE
     #define ARMA_HAVE_LOG1P
@@ -319,7 +301,7 @@
     // TODO: check the status of support for "extern thread_local" in clang shipped with Mac OS X
   #endif
   
-  #if (defined(_POSIX_C_SOURCE) && (_POSIX_C_SOURCE >= 200112L))
+  #if !defined(ARMA_USE_CXX11) && (defined(_POSIX_C_SOURCE) && (_POSIX_C_SOURCE >= 200112L))
     #define ARMA_HAVE_SNPRINTF
     #define ARMA_HAVE_ISFINITE
     #define ARMA_HAVE_LOG1P
@@ -332,7 +314,7 @@
 
 #if defined(__INTEL_COMPILER)
   
-  #if (__INTEL_COMPILER_BUILD_DATE < 20090623)
+  #if (__INTEL_COMPILER < 1300)
     #error "*** Need a newer compiler ***"
   #endif
   
@@ -340,27 +322,26 @@
   #undef  ARMA_HAVE_ICC_ASSUME_ALIGNED
   #define ARMA_HAVE_ICC_ASSUME_ALIGNED
   
+  #if defined(ARMA_USE_CXX11)
+    #if (__INTEL_COMPILER < 1500)
+      #undef  ARMA_PRINT_CXX11_WARNING
+      #define ARMA_PRINT_CXX11_WARNING
+    #endif
+  #endif
+  
 #endif
 
 
 #if defined(_MSC_VER)
   
-  #if (_MSC_VER < 1600)
-    #error "*** Need a newer compiler ***"
-  #endif
-  
   #if (_MSC_VER < 1700)
-    #pragma message ("WARNING: this compiler is OUTDATED and has INCOMPLETE support for the C++ standard;")
-    #pragma message ("WARNING: if something breaks, you get to keep all the pieces")
-    #define ARMA_BAD_COMPILER
+    #error "*** Need a newer compiler ***"
   #endif
   
   #if defined(ARMA_USE_CXX11)
     #if (_MSC_VER < 1900)
-      #pragma message ("WARNING: compiler is in C++11 mode, but it has INCOMPLETE support for C++11 features;")
-      #pragma message ("WARNING: if something breaks, you get to keep all the pieces.")
-      #pragma message ("WARNING: to forcefully prevent Armadillo from using C++11 features,")
-      #pragma message ("WARNING: #define ARMA_DONT_USE_CXX11 before #include <armadillo>")
+      #undef  ARMA_PRINT_CXX11_WARNING
+      #define ARMA_PRINT_CXX11_WARNING
     #endif
   #endif
   
@@ -419,7 +400,36 @@
   #if (__SUNPRO_CC < 0x5100)
     #error "*** Need a newer compiler ***"
   #endif
-    
+  
+  #if defined(ARMA_USE_CXX11)
+    #if (__SUNPRO_CC < 0x5130)
+      #undef  ARMA_PRINT_CXX11_WARNING
+      #define ARMA_PRINT_CXX11_WARNING
+    #endif
+  #endif
+  
+#endif
+
+
+#if defined(ARMA_USE_CXX11) && defined(__CYGWIN__)
+  #pragma message ("WARNING: Cygwin may have incomplete support for C++11 features.")
+#endif
+
+
+#if defined(ARMA_USE_CXX11) && (__cplusplus < 201103L)
+  #undef  ARMA_PRINT_CXX11_WARNING
+  #define ARMA_PRINT_CXX11_WARNING
+#endif
+
+
+#if defined(ARMA_PRINT_CXX11_WARNING)
+  #pragma message ("WARNING: use of C++11 features has been enabled,")
+  #pragma message ("WARNING: but this compiler has INCOMPLETE support for C++11;")
+  #pragma message ("WARNING: if something breaks, you get to keep all the pieces.")
+  #pragma message ("WARNING: to forcefully prevent Armadillo from using C++11 features,")
+  #pragma message ("WARNING: #define ARMA_DONT_USE_CXX11 before #include <armadillo>")
+
+  #undef ARMA_PRINT_CXX11_WARNING
 #endif
 
 
