@@ -1,10 +1,12 @@
-// Copyright (C) 2009-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2009-2010 Conrad Sanderson
-// Copyright (C) 2009-2010 Dimitrios Bouzas
+// Copyright (C) 2009-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Written by Dimitrios Bouzas
 
 
 
@@ -13,9 +15,8 @@
 
 
 
-//! \brief
-//! eps version for non-complex matrices and vectors
 template<typename T1>
+arma_warn_unused
 inline
 const eOp<T1, eop_eps>
 eps(const Base<typename T1::elem_type, T1>& X, const typename arma_not_cx<typename T1::elem_type>::result* junk = 0)
@@ -28,15 +29,13 @@ eps(const Base<typename T1::elem_type, T1>& X, const typename arma_not_cx<typena
 
 
 
-//! \brief
-//! eps version for complex matrices and vectors
 template<typename T1>
+arma_warn_unused
 inline
 Mat< typename T1::pod_type >
 eps(const Base< std::complex<typename T1::pod_type>, T1>& X, const typename arma_cx_only<typename T1::elem_type>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
-  
   arma_ignore(junk);
   
   typedef typename T1::pod_type   T;
@@ -48,23 +47,23 @@ eps(const Base< std::complex<typename T1::pod_type>, T1>& X, const typename arma
   Mat<T> out(A.n_rows, A.n_cols);
   
          T* out_mem = out.memptr();
-  const eT* A_mem   = A.memptr();
-  const uword n_elem  = A.n_elem;
+  const eT*   A_mem =   A.memptr();
+  
+  const uword n_elem = A.n_elem;
   
   for(uword i=0; i<n_elem; ++i)
     {
     out_mem[i] = eop_aux::direct_eps( A_mem[i] );
     }
   
-  
   return out;
   }
 
 
 
 template<typename eT>
-arma_inline
 arma_warn_unused
+arma_inline
 typename arma_integral_only<eT>::result
 eps(const eT& x)
   {
@@ -76,8 +75,8 @@ eps(const eT& x)
 
 
 template<typename eT>
-arma_inline
 arma_warn_unused
+arma_inline
 typename arma_real_only<eT>::result
 eps(const eT& x)
   {
@@ -87,8 +86,8 @@ eps(const eT& x)
 
 
 template<typename T>
-arma_inline
 arma_warn_unused
+arma_inline
 typename arma_real_only<T>::result
 eps(const std::complex<T>& x)
   {
