@@ -1,9 +1,11 @@
-// Copyright (C) 2009-2012 NICTA (www.nicta.com.au)
-// Copyright (C) 2009-2012 Conrad Sanderson
+// Copyright (C) 2009-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup fn_median
@@ -11,6 +13,7 @@
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const Op<T1, op_median>
 median
@@ -31,6 +34,7 @@ median
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 const Op<T1, op_median>
 median
@@ -49,8 +53,8 @@ median
 
 
 template<typename T1>
-inline
 arma_warn_unused
+inline
 typename T1::elem_type
 median
   (
@@ -69,8 +73,8 @@ median
 
 
 template<typename T>
-arma_inline
 arma_warn_unused
+arma_inline
 const typename arma_scalar_only<T>::result &
 median(const T& x)
   {
